==> telectron-1.2.16-py3-none-any.whl: telectron/raw/functions/phone/join_group_call.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class JoinGroupCall(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``129``
        - ID: ``0xb132ff7b``

    Parameters:
        call: :obj:`InputGroupCall <telectron.raw.base.InputGroupCall>`
        join_as: :obj:`InputPeer <telectron.raw.base.InputPeer>`
        params: :obj:`DataJSON <telectron.raw.base.DataJSON>`
        muted (optional): ``bool``
        video_muted (optional): ``bool``
        invite_hash (optional): ``str``

    Returns:
        :obj:`Updates <telectron.raw.base.Updates>`
    """

    __slots__: List[str] = ["call", "join_as", "params", "muted", "video_muted", "invite_hash"]

    ID = 0xb132ff7b
    QUALNAME = "functions.phone.JoinGroupCall"

    def __init__(self, *, call: "raw.base.InputGroupCall", join_as: "raw.base.InputPeer", params: "raw.base.DataJSON", muted: Union[None, bool] = None, video_muted: Union[None, bool] = None, invite_hash: Union[None, str] = None) -> None:
        self.call = call  # InputGroupCall
        self.join_as = join_as  # InputPeer
        self.params = params  # DataJSON
        self.muted = muted  # flags.0?true
        self.video_muted = video_muted  # flags.2?true
        self.invite_hash = invite_hash  # flags.1?string

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "JoinGroupCall":
        flags = Int.read(data)
        
        muted = True if flags & (1 << 0) else False
        video_muted = True if flags & (1 << 2) else False
        call = TLObject.read(data)
        
        join_as = TLObject.read(data)
        
        invite_hash = String.read(data) if flags & (1 << 1) else None
        params = TLObject.read(data)
        
        return JoinGroupCall(call=call, join_as=join_as, params=params, muted=muted, video_muted=video_muted, invite_hash=invite_hash)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.muted else 0
        flags |= (1 << 2) if self.video_muted else 0
        flags |= (1 << 1) if self.invite_hash is not None else 0
        data.write(Int(flags))
        
        data.write(self.call.write())
        
        data.write(self.join_as.write())
        
        if self.invite_hash is not None:
            data.write(String(self.invite_hash))
        
        data.write(self.params.write())
        
        return data.getvalue()

==> telectron-1.2.23-py3-none-any.whl: telectron/raw/functions/phone/join_group_call.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class JoinGroupCall(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``129``
        - ID: ``0xb132ff7b``

    Parameters:
        call: :obj:`InputGroupCall <telectron.raw.base.InputGroupCall>`
        join_as: :obj:`InputPeer <telectron.raw.base.InputPeer>`
        params: :obj:`DataJSON <telectron.raw.base.DataJSON>`
        muted (optional): ``bool``
        video_stopped (optional): ``bool``
        invite_hash (optional): ``str``

    Returns:
        :obj:`Updates <telectron.raw.base.Updates>`
    """

    __slots__: List[str] = ["call", "join_as", "params", "muted", "video_stopped", "invite_hash"]

    ID = 0xb132ff7b
    QUALNAME = "functions.phone.JoinGroupCall"

    def __init__(self, *, call: "raw.base.InputGroupCall", join_as: "raw.base.InputPeer", params: "raw.base.DataJSON", muted: Union[None, bool] = None, video_stopped: Union[None, bool] = None, invite_hash: Union[None, str] = None) -> None:
        self.call = call  # InputGroupCall
        self.join_as = join_as  # InputPeer
        self.params = params  # DataJSON
        self.muted = muted  # flags.0?true
        self.video_stopped = video_stopped  # flags.2?true
        self.invite_hash = invite_hash  # flags.1?string

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "JoinGroupCall":
        flags = Int.read(data)
        
        muted = True if flags & (1 << 0) else False
        video_stopped = True if flags & (1 << 2) else False
        call = TLObject.read(data)
        
        join_as = TLObject.read(data)
        
        invite_hash = String.read(data) if flags & (1 << 1) else None
        params = TLObject.read(data)
        
        return JoinGroupCall(call=call, join_as=join_as, params=params, muted=muted, video_stopped=video_stopped, invite_hash=invite_hash)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.muted else 0
        flags |= (1 << 2) if self.video_stopped else 0
        flags |= (1 << 1) if self.invite_hash is not None else 0
        data.write(Int(flags))
        
        data.write(self.call.write())
        
        data.write(self.join_as.write())
        
        if self.invite_hash is not None:
            data.write(String(self.invite_hash))
        
        data.write(self.params.write())
        
        return data.getvalue()
